test_sam2paf_v1.sam contains 100 alignements see create_.sh for details
test_sam2paf_bad1.sam has a bad headedr (missing LN)
test_sam2paf_bad1.sam had inconsistent QUAL and SEQ lengths
test_sam2paf_extra.sam had contains 10 dummy alignment to test all cigar combo
